@@ -1,3 +1,5 @@
+# (c) cavaliba.com - data - field - datetime
+
 import datetime
 
 from .field import Field
@@ -7,24 +9,26 @@ from .field import Field
 # -------------
 class FieldDatetime(Field):
 
-    def merge_edit_data(self, data):
-        self.value = []
-        for i in data:
-            if len(i) > 0:
-                self.value.append(i)
+    # 'YYYY-MM-DD hh:mm:ss'
 
-    def merge_new_data(self, data):
+    def merge_import(self, data):
+        # no split composite !
         self.value = []
-        for i in data:
-            if len(i) > 0:
-                self.value.append(i)
-                
+        if type(data) is str:
+            if len(data) == 19:
+                self.value = [data]
+        elif type(data) is list:
+            for i in data:
+                if len(i) == 19:
+                    self.value.append(i)
+
+
     def is_valid(self):
         r = super().is_valid()
         for v in self.value:
             if type(v) is str:
-                if len(v) == 0:
-                    continue            
+                if len(v) != 19:
+                    return False            
             try:
                 timeformat = "%Y-%m-%d %H:%M:%S"
                 validtime = datetime.datetime.strptime(v, timeformat)
