@@ -43,9 +43,10 @@ class DataClass(models.Model):
 
     class Meta:
         #db_table = "{{ app_name}}_category"
+        db_table = "data_schema"
         ordering = ['keyname']
-        verbose_name = "Cavaliba Data Class"
-        verbose_name_plural = "Cavaliba Data Classes"
+        verbose_name = "Data Schema"
+        verbose_name_plural = "Data Schemas"
 
 
     # def natural_key(self):
@@ -119,11 +120,11 @@ class DataSchema(models.Model):
     ###p_delete = models.CharField(max_length=256,  null=True, blank=True)
 
     class Meta:
-        #db_table = "{{ app_name}}_category"
+        db_table = "data_field"
         unique_together = ["classobj", "keyname"]
         ordering = ['classobj','keyname','order']
-        verbose_name = "Cavaliba Data Schema"
-        verbose_name_plural = "Cavaliba Data Schema"
+        verbose_name = "Data Field"
+        verbose_name_plural = "Data Fields"
 
 
     # def natural_key(self):
@@ -138,20 +139,13 @@ class DataSchema(models.Model):
 # ----------------------------------------------------------------------------------
 
 
-# class DataInstanceManager(models.Manager):
-#     def get_by_natural_key(self, keyname, classname):
-#         return self.get(keyname=keyname, classname=classname)
-
-
 class DataInstance(models.Model):
 
     # will be removed
     classobj = models.ForeignKey("DataClass", on_delete=models.CASCADE)
-    # new V3.19
+
     classname = models.SlugField("Schema", max_length=128, null=True, blank=True)
-
     keyname = models.CharField(max_length=256, null=False, blank=False)
-
     displayname = models.CharField(max_length=500,  null=True, blank=True)
     is_enabled = models.BooleanField(default=True)
 
@@ -165,7 +159,7 @@ class DataInstance(models.Model):
     last_update = models.DateTimeField(_("Last update"), auto_now_add=False, blank=True, null=True)
  
     class Meta:
-        #db_table = "{{ app_name}}_category"
+        db_table = "data_instance"
         indexes = [
             models.Index(fields=["classobj"]),
             models.Index(fields=["keyname"]),
@@ -175,8 +169,8 @@ class DataInstance(models.Model):
             ]
         unique_together = ["classobj", "keyname"]
         ordering = ['classobj','keyname']
-        verbose_name = "Cavaliba Data Instance"
-        verbose_name_plural = "Cavaliba Data Instances"
+        verbose_name = "Data Instance"
+        verbose_name_plural = "Data Instances"
 
     # def natural_key(self):
     #         return (self.classname, self.keyname)
@@ -190,6 +184,33 @@ class DataInstance(models.Model):
             return f"{self.keyname}"
 
 
+# ----------------------------------------------------------------------------------
+# DataRevision - v3.23
+# ----------------------------------------------------------------------------------
+
+class DataRevision(models.Model):
+
+    date = models.DateTimeField(auto_now_add=True, blank=False, null=False)
+    classname = models.SlugField("Schema", max_length=128, null=False, blank=False)
+    keyname = models.CharField(max_length=256, null=False, blank=False)
+    username = models.CharField(max_length=256, null=True, blank=True)
+    action = models.CharField(max_length=256, null=True, blank=True)
+    # next: data_diff old/new
+
+    class Meta:
+        db_table = "data_revision"
+        indexes = [
+            models.Index(fields=["date"]),
+            models.Index(fields=["classname","keyname"]),
+            ]
+        verbose_name = "Data Revision"
+        verbose_name_plural = "Data Revisions"
+
+
+    def __str__(self):
+        return f"{self.date} {self.classname} {self.keyname} {self.action}"
+ 
+
 
 # ----------------------------------------------------------------------------------
 # DataRegistry - v3.16
@@ -207,7 +228,7 @@ class DataRegistry(models.Model):
         return f"{self.key}"
 
     class Meta:
-        db_table = "registry"
+        db_table = "data_registry"
         ordering = ['key']
         verbose_name = "Registry entry"
         verbose_name_plural = "Registry entries"
@@ -237,9 +258,9 @@ class DataEAV(models.Model):
 
 
     class Meta:
-        db_table = "data_eav"
-        verbose_name = "Data EAV"
-        verbose_name_plural = "Data EAV"
+        db_table = "data_cache"
+        verbose_name = "Data Cache"
+        verbose_name_plural = "Data Cache"
         indexes = [
             models.Index(fields=["iid"]),
             models.Index(fields=["classname"]),
