@@ -43,6 +43,10 @@ from app_data.eav import eav_from_field
 from app_data.filestore import uuid_to_queryset
 from app_data.schema import Schema
 
+from app_data.revision import revision_add
+from app_data.revision import revision_get
+from app_data.revision import revision_purge
+
 from app_sirene.notify import create_notification
 
 
@@ -57,6 +61,7 @@ def private(request):
         return redirect(context["redirect"])
     aaa = context["aaa"]
 
+
     dataclasses = get_classes(is_enabled=True)
     filtered = []
 
@@ -110,6 +115,14 @@ def instance_list(request, classname=None):
         return redirect(context["redirect"])
     aaa = context["aaa"]
 
+
+
+    # TEST:
+    count = revision_purge()
+    print("$$$$ count purge=",count)
+
+
+    
     classobj = get_class_by_name(classname)
     if not classobj:
         redirect("app_data:private")
@@ -128,6 +141,7 @@ def instance_list(request, classname=None):
 
     # apply permission & dataview
     dataview = dataview_for_request(request=request, classname=classname, update_session=True)
+    # TODO: remove
     schema = get_schema(classname=classname)
     filtered = []
     for iobj in db_instances:
@@ -234,6 +248,11 @@ def instance_detail(request, id=None):
         if 'p_sirene_new' in aaa['perms']:
             context['ui_sirene'] = True
 
+    # revisions - V3.23
+    context['revisions'] = revision_get(classname=classname, keyname=instance.keyname)
+    if len(context['revisions']) == 0:
+        del context['revisions']
+
     # related objects
     context['related'] = instance.get_related()
 
@@ -303,6 +322,7 @@ def instance_new(request, classname=None):
        
     
             if r:
+                revision_add(aaa=aaa, instance=instance, action="create")
                 messages.add_message(request, messages.SUCCESS, _("Instance created"))
                 log(INFO, aaa=aaa, app="data", view="instance_new", action="post", status="OK", data=f"{classname}/{instance.keyname}")                 
                 return redirect("app_data:instance_list", classname)
@@ -393,6 +413,7 @@ def instance_edit(request, id=None):
                 r = instance.update()
 
             if r:
+                revision_add(aaa=aaa, instance=instance, action="edit")
                 messages.add_message(request, messages.SUCCESS, _("Instance updated"))
                 log(INFO, aaa=aaa, app="data", view="instance_edit", action="post", status="OK", data=f"{classname}:{instance.keyname}") 
                 #return redirect("app_data:instance_list", classname)
@@ -450,7 +471,6 @@ def instance_delete(request, id=None):
         return redirect("app_data:private")
     
     classname = instance.classname
-    classobj = instance.classobj
 
     # Check PERMISSIONS
     if not instance.has_delete_permission(aaa=aaa):
@@ -464,6 +484,7 @@ def instance_delete(request, id=None):
 
         r = instance.delete()
         if r:
+            revision_add(aaa=aaa, instance=instance, action="delete")
             messages.add_message(request, messages.SUCCESS, _("Instance deleted"))
             log(INFO, aaa=aaa, app="data", view="instance_delete", action="post", status="OK", 
                 data=f"{classname}:{instance.keyname}")
@@ -566,7 +587,7 @@ def data_export(request):
         log(WARNING, aaa=aaa, app="data", view="export", action="post", status="KO", data=f"Export may be truncated for {classname} - {max_size}") 
         messages.add_message(request, messages.WARNING, _("Export may be truncated (size max reached)"))
 
-
+    # TODO: remove
     schema = get_schema(classname=classname)
 
     if dataview:
