@@ -27,9 +27,6 @@ from app_user.user import user_get_by_login
 from app_user.user import user_get_by_id
 from app_user.user import user_create
 
-from app_user.group import group_get_users
-
-
 from app_user.role import role_get_by_name
 
 
@@ -231,7 +228,8 @@ def start_view(request, app="na", view="na", noauth=None, perm=None, noauthz=Non
 # user_ip            : 
 # perms:[]           : [perm_keyname, ...]
 # groups:[]          : [groupnames, ...]  => all groups for aaa
-# groups_direct:[]   : [groupnames, ...]  => direct membership (user is in group) + computed autogroup rules
+# groups_direct:[]   : [groupnames, ...]  => direct membership (user is in group)
+# groups_computed:[] : [groupnames, ...]  => computed (autogroup) groupnames for user
 # groups_indirect:[] : [groupnames, ...]  => parent groups for direct_group
 # impersonate_by     : login of source account ; default ""
 # ----------------------------------------------------------------------
@@ -511,8 +509,8 @@ def get_aaa(request, auth_mode = None, impersonate=None, impersonate_by=None):
     # ----------------
     # Authorizations
     # ----------------
-    aaa["groups_direct"], aaa["groups_indirect"] = get_groups_for_user(user, mode="name")
-    aaa["groups"] = list(set(aaa["groups_direct"] + aaa["groups_indirect"]))
+    aaa["groups_direct"], aaa["groups_computed"], aaa["groups_indirect"] = get_groups_for_user(user, mode="name")
+    aaa["groups"] = list(set(aaa["groups_direct"] + aaa["groups_computed"] + aaa["groups_indirect"]))
 
     # add perms & roles to aaa 
     tmp = get_permissions_for_aaa(aaa)
@@ -616,7 +614,9 @@ def get_groups_for_user(user, mode="name"):
     # 2. computed groups from autogroup
     # TODO
     # direct.append() ...
-    direct = list(set(direct))
+    computed = list(SireneGroup.objects.filter(is_enabled = True, autogroup_users__in=[user]).distinct())
+
+    #direct = list(set(direct))
 
 
     # 3. parent groups
@@ -645,13 +645,13 @@ def get_groups_for_user(user, mode="name"):
 
     # convert to name only (e.g. JSON serialize to celery)
     if mode == "name":
+        computed_name = [i.keyname for i in computed]
         indirect_name = [i.keyname for i in indirect]
         direct_name = [i.keyname for i in direct]
-        return direct_name, indirect_name
-    
+        return direct_name, computed_name, indirect_name
     # gobj
     else:
-        return direct, indirect
+        return direct, computed, indirect
 
 
 # ---------------------------------------
