@@ -214,6 +214,14 @@ class GroupForm(forms.Form):
         widget=forms.TextInput(attrs={'size':80})
         )
 
+    autogroup = forms.CharField(required=False,
+        label=_("Autogroup"),
+        widget=forms.TextInput(attrs={'size':80}),
+        help_text = _("Automatically add users from rule, either schema:*:field or schema:keyname:* pattern"),
+        #widget=forms.Textarea(attrs={'cols':80})
+        #widget=TinyMCE(attrs={'cols': 60, 'rows': 30})
+        )
+    
     subgroups = forms.ModelMultipleChoiceField(required=False,
         label = _("Subgroups"),
         help_text = _("Select sub-groups members of this group."),
@@ -222,6 +230,7 @@ class GroupForm(forms.Form):
         )
 
 
+    
 
 # File Import Form
 class GroupUploadForm(forms.Form):
