@@ -249,6 +249,21 @@ def group_get_users_computed_g2(group, schema_name, keyname):
 
     return reply
 
+# update cache
+def group_autogroup_update(groups=None):
+    
+    count = 0
+    if not groups:
+        groups = SireneGroup.objects.filter(is_enabled=True, is_role=False).all()
+    for group in groups:
+        users = group_get_users_computed(group)
+        if len(users) > 0:
+            count += 1
+        group.autogroup_users.set(users)
+        group.save()
+
+    return count
+
 
 
 # ------------------------------------
@@ -421,9 +436,9 @@ def group_delete(gobj):
     
     try:
         gobj.delete()
-        return True
+        return gobj
     except Exception as e:
-        print("group_delete failed : ",e)
+        #print("group_delete failed : ",e)
         return False
 
 # X
