@@ -22,12 +22,15 @@ from app_user.group import group_create   # or update
 from app_user.group import group_get_form
 from app_user.group import group_get_subgroups
 from app_user.group import group_get_users
+from app_user.group import group_autogroup_update
 
 from app_data.permissions import has_group_read_permission
 from app_data.permissions import has_group_update_permission
 from app_data.permissions import has_group_create_permission
 from app_data.permissions import has_group_delete_permission
 
+from app_data.revision import revision_add_raw
+from app_data.revision import revision_get
 
 # TODO: check per-group permissions
 
@@ -121,6 +124,10 @@ def detail(request, gid=None):
         log(WARNING, aaa=aaa, app="iam", view="group", action="detail", status="KO", data=_("Not allowed") )
         return redirect("app_user:group_list")
 
+    # c = group_autogroup_update()
+    # print("$$$ autogroup = ",c)
+    # update autogroup_users (don't wait for periodic task)
+    group_autogroup_update([group])
 
     # main group object
     context["group"] = group
@@ -134,6 +141,10 @@ def detail(request, gid=None):
     context["users_computed"] = group_get_users(group, direct=False, computed=True, subgroups=False)
     context["users_indirect"] = group_get_users(group, direct=False, computed=False, subgroups=True)
 
+    # revisions - V3.23
+    context['revisions'] = revision_get(classname="_group", keyname=group.keyname)
+
+
     # can use YAML Editor ?
     if 'p_data_import' in aaa['perms']:
         context['ui_texteditor'] = True
@@ -183,6 +194,7 @@ def edit(request, gid=None):
             users = request.POST.getlist("users",default=[])
             data["users"] = users
 
+            action = "edit"
             # update
             if group:
                 group = group_update(group, data)
@@ -190,8 +202,10 @@ def edit(request, gid=None):
             # create                
             else:   
                 group = group_create(data)
+                action = "create"
     
             if group:
+                revision_add_raw(aaa=aaa, classname="_group", keyname=group.keyname, action=action)
                 messages.add_message(request, messages.SUCCESS, _("Group saved") )
                 log(INFO, aaa=aaa, app="iam", view="group", action="save", status="OK", data=f"saved: {group.keyname}")
           
@@ -263,11 +277,12 @@ def delete(request, gid):
 
     if request.method == "POST":
 
-        r = group_delete(gobj)
+        group = group_delete(gobj)
 
-        if r:
+        if group:
+            revision_add_raw(aaa=aaa, classname="_group", keyname=group.keyname, action="delete")
             messages.add_message(request, messages.SUCCESS, _("Group deleted ") )
-            log(INFO, aaa=aaa, app="iam", view="group_delete", action="delete", status="OK", data=f"deleted: {gobj.keyname}" )
+            log(INFO, aaa=aaa, app="iam", view="group_delete", action="delete", status="OK", data=f"deleted: {group.keyname}" )
 
         else:
             log(ERROR, aaa=aaa, app="iam", view="group_delete", action="delete", status="FAIL", data=_("Failed to delete group") )
