@@ -49,6 +49,7 @@ class SireneUser(models.Model):
 
 
     class Meta:
+        db_table = "iam_user"
         ordering = ['login']
         verbose_name = "Sirene User"
         verbose_name_plural = "Sirene Users"
@@ -115,11 +116,14 @@ class SireneGroup(models.Model):
 
     # 3.22 : grammar field for dynamic (compouted groups)
     autogroup = models.TextField(_('Autogroup'), null=True, blank=True)
+    # cached computed users
+    autogroup_users = models.ManyToManyField(SireneUser, related_name="+", blank=True)
 
     last_update = models.DateTimeField(_("Last update"), auto_now_add=False, blank=True, null=True)
 
 
     class Meta:
+        db_table = "iam_group"
         ordering = ['keyname']
         verbose_name = "Sirene Group"
         verbose_name_plural = "Sirene Groups"
@@ -153,6 +157,7 @@ class SirenePermission(models.Model):
 
 
     class Meta:
+        db_table = "iam_permission"
         ordering = ['keyname']
         verbose_name = "Sirene Permission"
         verbose_name_plural = "Sirene Permissions"
@@ -177,6 +182,7 @@ class SireneVisitor(models.Model):
 
 
     class Meta:
+        db_table = "iam_visitor"
         ordering = ['last_login']
         verbose_name = "Sirene Visitor"
         verbose_name_plural = "Sirene Visitors"
