@@ -301,9 +301,9 @@ def role_delete(gobj):
 
     try:
         gobj.delete()
-        return True
+        return gobj
     except Exception as e:
-        print("role_delete failed : ",e)
+        #print("role_delete failed : ",e)
         return False
 
 # 0
