@@ -63,6 +63,8 @@ from app_sirene.notify import task_send_mail
 from app_sirene.notify import task_send_sms
 
 from app_data.permissions import has_iam_export_permission
+from app_data.revision import revision_add_raw
+from app_data.revision import revision_get
 
 # from app_data.permissions import has_user_read_permission
 # from app_data.permissions import has_user_update_permission
@@ -242,6 +244,7 @@ def delete(request, userid):
         user = user_delete_by_id(userid=userid) 
 
         if user:
+            revision_add_raw(aaa=aaa, classname="_user", keyname=user.login, action="delete")
             messages.add_message(request, messages.SUCCESS, _("User deleted"))
             log(INFO, aaa=aaa, app="iam", view="user_delete", action="delete", status="OK", data=f"{user.login}") 
         else:
@@ -273,8 +276,9 @@ def detail(request, userid=None):
     log(DEBUG, aaa=aaa, app="iam", view="user", action="detail", status="OK", data=user.login )
 
     # get group objects
-    direct,indirect = get_groups_for_user(user, mode="obj")
+    direct, computed, indirect = get_groups_for_user(user, mode="obj")
     context["direct"] = direct
+    context["computed"] = computed
     context["indirect"] = indirect
 
     permissions = []
@@ -288,6 +292,10 @@ def detail(request, userid=None):
                 permissions.append(p)
     context["permissions"] = permissions
 
+    # revisions - V3.23
+    context['revisions'] = revision_get(classname="_user", keyname=user.login)
+
+
     # can use YAML Editor ?
     if 'p_data_import' in aaa['perms']:
         context['ui_texteditor'] = True
@@ -335,15 +343,18 @@ def edit(request, userid=None):
         
         if form.is_valid():
 
+            action = "create"
             # update
             if user:
                 user = user_update(user, form.cleaned_data)
+                action="edit"
             # create                
             else:
                 user = user_create(data=form.cleaned_data)
             
             # success ?
             if user:
+                revision_add_raw(aaa=aaa, classname="_user", keyname=user.login, action=action)
                 messages.add_message(request, messages.SUCCESS, _("User saved : ") + user.login )
                 log(INFO, aaa=aaa, app="iam", view="edit", action="save", status="OK", data=f"{user.login}")
             else:
