@@ -222,29 +222,22 @@ CELERY_BEAT_SCHEDULE = {
     #     #"schedule": crontab(minute="*/1"),
     #     #'schedule': crontab(hour=7, minute=30, day_of_week=1),
     #     "schedule": 3.0,
+    #     "schedule": crontab(hour=19, minute=12),
     #     "args": ("hello",)
     # },
     "housekeeping_daily": {
         "task": "app_home.tasks.housekeeping_daily",
         "schedule": crontab(hour=HOUSEKEEPING_HOUR, minute=HOUSEKEEPING_MINUTE),
     },
-    # "data_housekeeping_daily": {
-    #     "task": "app_data.tasks.data_housekeeping_daily",
-    #     "schedule": crontab(hour=20, minute=10),
-    # },
-    # "log_purge": {
-    #     "task": "app_home.tasks.log_purge",
-    #     "schedule": crontab(hour=20, minute=42),
-    # },
-    # "clear_expired_sessions": {
-    #     "task": "app_home.tasks.clear_expired_sessions",
-    #     "schedule": crontab(hour=20, minute=45),
-    # },
     "archive_expired_sirene": {
         "task": "app_sirene.notify.archive_expired_sirene",
         "schedule": 60.0,
-        #"schedule": crontab(hour=19, minute=12),
     },
+    # 3.22 - autogroup cache update
+    "iam_autogroup_update": {
+        "task": "app_user.tasks.task_autogroup_update",
+        "schedule": 60.0,
+    },    
     "status_run_monitor": {
         "task": "app_status.tasks.task_run_monitor",
         "schedule": 15.0,
