@@ -289,7 +289,8 @@ class IAMTest(TestCase):
 
         gobj = group_get_by_name("group_unittest")
         r = group_delete(gobj)
-        self.assertEqual(r, True)
+        self.assertIsNot(r, False)
+        self.assertIsInstance(r, SireneGroup)
 
         # non-existent group
         gobj = group_get_by_name("group_unittest2")
